;; Add the site directory (used to contain non-core Emacs Lisp packages) to the Emacs load-path, 
;; i.e., the list of directories where Emacs searches for packages that you require. 
;; This must be at the head of your .emacs file.  This code prepends the site directory to the load path: 
;; For other packages:
;; For Emacs JDE (from http://sunsite.dk/jde/):
(add-to-list 'load-path (expand-file-name "~/code/emacs/site/jde-latest/jde-2.2.6/lisp"))
(add-to-list 'load-path (expand-file-name "~/code/emacs/site/eieio-0.15"))
(add-to-list 'load-path (expand-file-name "~/code/emacs/site/semantic-1.3.2"))
(add-to-list 'load-path (expand-file-name "~/code/emacs/site/speedbar-0.13a"))
(add-to-list 'load-path (expand-file-name "~/code/emacs/site/elib/pub/comp/os/unix/gnu/elib/elib-1.0"))
(add-to-list 'load-path (expand-file-name "~/"))
(add-to-list 'load-path (expand-file-name "~/emacs/site/"))
;; For use of Bash shell via Cygwin on Windows 2000 (or NT), available from:
;;	     http://www.cygwin.com/
;; (if you do not have Cygwin installed, comment all of this section out).
	;; This assumes that Cygwin is installed in C:\cygwin (the
	;; default) and that C:\cygwin\bin is not already in your
	;; Windows Path (it generally should not be).
        ;;
	(setq exec-path (cons "C:/cygwin/bin" exec-path))
	(setenv "PATH" (concat "C:\\cygwin\\bin;" (getenv "PATH")))
	;;
	;; NT-emacs assumes a Windows command shell, which you change
	;; here.
	;;
	(setq process-coding-system-alist '(("bash" . undecided-unix)))
	(setq w32-quote-process-args ?\")
	(setq shell-file-name "bash")
	(setenv "SHELL" shell-file-name) 
	(setq explicit-shell-file-name shell-file-name) 

	;;
	;; This removes unsightly ^M characters that would otherwise
	;; appear in the output of java applications.
	;;
	(add-hook 'comint-output-filter-functions
		  'comint-strip-ctrl-m)
;; End of bash shell use via Cygwin section.


;; This removes unsightly ^M characters that would otherwise
;; appear in the output of java applications.
;;
(add-hook 'comint-output-filter-functions
	  'comint-strip-ctrl-m)

;; Set start-up directory with cygwin nomenclature:
(setq startup-directory "~/code/development/")

(require 'jde)

;; This is for the css-mode (will not be necessary in later versions; it should 
;; be in the css-mode code itself):
(require 'apropos)  

;; For css-mode: (from http://www.garshol.priv.no/download/software/css-mode/)
 (autoload 'css-mode "css-mode.el")
 (setq auto-mode-alist	     
      (cons '("\\.css\\'" . css-mode) auto-mode-alist))

(diary) 

(display-time)
(add-hook 'diary-hook 'appt-make-list)
(diary 0)

(global-font-lock-mode t)

(setq-default transient-mark-mode t)

;; Global key maps:
(global-set-key "\C-b" 'browse-url-of-file)
(global-set-key "\e/" 'replace-regexp)
(global-set-key "\C-xtl" 'goto-line)
(global-set-key "\e[" 'enlarge-window)
(global-set-key "\e]" 'shrink-window)
(global-set-key "\e=" 'eval-current-buffer)

;; These two key bindings are for up and down scrolling by a either single line at a time
;; or by N lines at a time (default is scroll by one single line at a time).  This is 
;; very useful when working with narrow horizontal windows.  ;~)
;; To enter the desired N, hold down \C and type the number and then hit z or q, all the
;; while holding down \C.
;; From the "Writing GNU Emacs Extensions" book, by Bob Glickstein.
(defun scroll-n-lines-up (&optional n) 
  "Scroll up N lines (1 line by default)."
  (interactive "P")
  (scroll-up (prefix-numeric-value n)))

(defun scroll-n-lines-down (&optional n) 
  "Scroll down N lines (1 line by default)."
  (interactive "P")
  (scroll-down (prefix-numeric-value n)))

(global-set-key "\C-q" 'scroll-n-lines-up)
(global-set-key "\C-z" 'scroll-n-lines-down)


;; These two bindings make it easier to find a mismatched parenthesis:
(global-set-key "\e'" 'forward-sexp)
(global-set-key "\e;" 'backward-sexp)

;; This loads a major mode for javascript, obtained from this url: (not working yet)
;; <http://www.brigadoon.de/peter/javascript-mode.el>
;;(load "tempo") 
;;(load "browse-url")

;;(autoload 'javascript-mode "javascript-mode.el" t)
;;(setq auto-mode-alist (append '(("\\.js$" . javascript-mode))
;;			   auto-mode-alist))

;; This is my old way of loading c-mode and hooking .js files to it, 
;; NOT superseded by the major mode loaded just above.
(autoload 'c-mode "cc-mode.el")
(setq auto-mode-alist (cons '("\.js$" . c-mode) auto-mode-alist))
(add-hook 'emacs-mode-hook 'turn-on-font-lock) 

;;; Bracket/brace/parentheses highlighting:
   ;; The following is the command for Emacs 20.1 and later:
(show-paren-mode 1)
   ;; * Here is some Emacs Lisp that will make the % key show the matching
   ;; parenthesis, like in vi.	In addition, if the cursor isn't over a
   ;; parenthesis, it simply inserts a % like normal.  (`Parenthesis' actually
   ;;  includes and character with `open' or `close' syntax, which usually means
   ;;  "()[]{}".)

      ;; By an unknown contributor

      (global-set-key "%" 'match-paren)

      (defun match-paren (arg)
	"Go to the matching parenthesis if on parenthesis otherwise insert %."
	(interactive "p")
	(cond ((looking-at "\\s\(") (forward-list 1) (backward-char 1))
	      ((looking-at "\\s\)") (forward-char 1) (backward-list 1))
	      (t (self-insert-command (or arg 1)))))



;; The following functions enable on-the-fly switching between the bash shell and DOS:
(defun set-shell-bash()
  (interactive)
  ;; (setq binary-process-input t)
  (setq shell-file-name "bash")
  (setq shell-command-switch "-c")
  (setq explicit-shell-file-name "bash")
  (setenv "SHELL" explicit-shell-file-name)
  (setq explicit-sh-args '("-login" "-i"))
  (setq w32-quote-process-args ?\")
  (setq mswindows-quote-process-args t)
  )

(defun set-shell-cmdproxy()
  (interactive)
  (setq shell-file-name "cmdproxy")
  (setq explicit-shell-file-name "cmdproxy")
  (setenv "SHELL" explicit-shell-file-name)
  (setq explicit-sh-args nil)
  (setq w32-quote-process-args nil)
  )

(global-set-key "\C-xg" 'set-shell-bash) ;; g for Gnu (\C-xb is used for buffer switch command).
(global-set-key "\C-xd" 'set-shell-cmdproxy)
;; End shell-switch on-the-fly.


;; Begin move-to-window block:
;; This code is from the O'Reilly "GNU Emacs Extensions" book.
;; The purpose of it is to make a reasonable way to move to the next OR previous window.
;; Change from C-x o to C-x n, so that we have Next and Previous.  
(global-set-key "\C-xn" 'other-window) 

;; We must make our own function to go to the previous window (but it's simple):
(defun other-window-backward ()
  "Select the previous window."
  (interactive)
  (other-window -1))
;; Now we can bind to this function:
(global-set-key "\C-xp" 'other-window-backward)
;; End move to window block.

;; This turns on the buffer select list in the minibuffer to make it easy to 
;; edit any buffer in a given window or frame (C-r and C-s move backwards and forwards, respectively, 
;; through the buffer select list).
(require 'iswitchb)
(iswitchb-default-keybindings)

;; old: (setq show-paren-mode t)
;; old: (setq show-paren-style 'parenthesis)

;; Set a high recursion limit for parsing the long java files:
(setq max-specpdl-size 1000)

(put 'upcase-region 'disabled nil)

(put 'downcase-region 'disabled nil)

;; Adjust the colors to preference:
(set-cursor-color "Deep Pink")
(set-foreground-color "Green")
(set-background-color "Gray10")
(set-face-foreground 'custom-group-tag-face "Yellow")
(set-face-foreground 'custom-variable-tag-face "Magenta")
(set-face-foreground 'custom-state-face "LightGray")
(set-face-foreground 'font-lock-type-face "Goldenrod")
(set-face-foreground 'font-lock-comment-face "OrangeRed")
(set-face-foreground 'font-lock-function-name-face "Turquoise")
(set-face-foreground 'font-lock-keyword-face "Yellow")
(set-face-foreground 'font-lock-string-face "Magenta")
(set-face-foreground 'font-lock-variable-name-face "Coral")
(set-face-foreground 'modeline "yellow")
(set-face-background 'modeline "purple4") 
(set-face-background 'region "MidnightBlue")
(set-face-background 'secondary-selection "dodger blue")
(set-face-foreground 'diary-face "Yellow")
(set-face-background 'holiday-face "Pink")
(set-face-foreground 'holiday-face "Red")
(set-face-foreground 'widget-field-face "Sienna")
(set-face-foreground 'widget-single-line-field-face "Firebrick")
(set-face-foreground 'widget-inactive-face "White")
(set-face-foreground 'widget-documentation-face "Coral")
(set-mouse-color "yellow")
(set-face-foreground 'highlight "orange" )
(set-face-background 'highlight "blue")
;; The following settings pertain to features that you may not have installed on your GNU Emacs:
  ;; Begin speedbar section:
(set-face-foreground 'speedbar-directory-face "Green")
(set-face-background 'speedbar-directory-face "Black")
(set-face-foreground 'speedbar-highlight-face "DarkSlateGray")
(set-face-background 'speedbar-highlight-face "Gold")
(set-face-background 'speedbar-file-face "MidnightBlue")
(set-face-foreground 'speedbar-file-face "Gold")
(set-face-background 'speedbar-button-face "Pink")
(set-face-foreground 'speedbar-tag-face "Orange")
  ;; End speedbar section. 
  ;; You may not want the following line if you do not have paren-matching running:
(set-face-foreground 'show-paren-match-face "Red")
  ;; The following line is only if you have semantic installed:
(set-face-foreground 'semantic-intangible-face "Gold")
  ;; The following line is only if you have the JDE installed:
(set-face-foreground 'jde-java-font-lock-link-face "Gold")


;; Gnus: using only for mail.
(setq gnus-select-method '(nntp "nntp1.ba.best.com"))


;; This checks to see if you've set the variable startup-directory and checks to
;; see if you've set it to a real directory.  If so, it will switch there.
(let ((working-directory (or startup-directory nil)))
  (if (and (and working-directory)
    (file-directory-p working-directory))
      (cd working-directory)))

;; Make sure that tabs are being used (default behavior, but doesn't hurt in case something got changed):
(setq indent-tabs-mode t)

;; Set the variable default-tab-width.
(setq default-tab-width 2)

;;; My additions end here.

;; This was automatically written by the Emacs customization utility:
(custom-set-variables
 '(browse-url-browser-function (quote browse-url-generic))
 '(mail-host-address "ChristopherBalz@yahoo.com")
 '(browse-url-generic-program "mozilla")
 '(tab-stop-list (quote (2 4 8 16 32 48 56 64 72 80 88 96 104 112 120)))
 '(speedbar-use-images nil)
 '(jde-auto-parse-max-buffer-size 0)
 '(frame-background-mode nil)
 '(user-mail-address "ChristopherBalz@yahoo.com")
 '(jde-setnu-mode-threshold 200000)
 '(jde-compile-option-verbose t)
 '(speedbar-show-unknown-files t)
 '(user-full-name "Christopher M. Balz"))
(custom-set-faces)
 
;; ---------- BEGIN BUG WORKAROUNDS SECTION:
;; This prevents dired from displaying itself in warning-face when the 
;; default-tab-width is set to 2. 
  (defadvice dired-readin (around ecm-dired-indent activate)
    "Prevent indentation in dired from using tabs."
    (let ((indent-tabs-mode nil))
      ad-do-it))

;; ---------- END BUG WORKAROUNDS SECTION:

;; Define an easy way to move up in a dired directory, 
;; To instantly view a file in the web browser (IE or whatever) (this needs a current directory argument to work better):
;; **NOTE: These bindings must be in a mode-hook, since dired isn't automatically
;; loaded on startup and so it's keymap is void until you go into dired. 
(add-hook `dired-mode-hook
  `(lambda ()
		 (define-key dired-mode-map "\C-w" 'dired-up-directory)
     (define-key dired-mode-map "\C-b" 'browse-url)))

;; This enables saving the current desktop on shutdown.
(desktop-load-default)
(desktop-read)







